@@ -40,6 +40,9 @@ class TestPoliticianNameCleaver(unittest.TestCase):
     def test_standardize_running_mate_names(self):
         self.assertEqual('John Kasich & Mary Taylor', str(PoliticianNameCleaver('Kasich, John & Taylor, Mary').parse()))
 
+    def test_standardize_running_mate_names_with_slash(self):
+        self.assertEqual('Mitt Romney & Paul D. Ryan', str(PoliticianNameCleaver('ROMNEY, MITT / RYAN, PAUL D.').parse()))
+
     def test_we_dont_need_no_steeenking_nicknames(self):
         self.assertEqual('Robert M McDonnell', str(PoliticianNameCleaver('McDonnell, Robert M (Bob)').parse()))
         self.assertEqual('John J Duncan Jr', str(PoliticianNameCleaver('John J (Jimmy) Duncan Jr (R)').parse()))
@@ -153,9 +156,6 @@ class TestOrganizationNameCleaver(unittest.TestCase):
     def test_handles_empty_names(self):
         self.assertEqual('', str(OrganizationNameCleaver('').parse()))
 
-    def test_coca_cola_bottling_co_of_new_england(self):
-        self.assertEqual('', str(OrganizationNameCleaver('COCA-COLA BOTTLING CO OF NEW ENGLAND').parse()))
-
 
 
 class TestIndividualNameCleaver(unittest.TestCase):
